use strict;
use Shiar_Sheet::Colour '1.02';

+{
	html => [
		{
			title => 'HTML keywords (inherited by CSS≥2.1 and SVG), mostly identical to X11',
			href => 'http://www.w3.org/TR/css3-color/#html4',
		},
		qw/000000:black 800000:maroon  008000:green 808000:olive
		   000080:navy  800080:purple  008080:cyan  C0C0C0:silver
		   808080:gray  FF0000:red     00FF00:lime  FFFF00:yellow
		   0000FF:blue  FF00FF:fuchsia 00FFFF:aqua  FFFFFF:white /,
	],
	cga => [
		{},  # linux console, kde?
		qw/000000 AA0000 00AA00 AA5500 0000AA AA00AA 00AAAA AAAAAA
		   555555 FF5555 55FF55 FFFF55 5555FF FF55FF 55FFFF FFFFFF/,
#		qw/reset bold dim italic underline blink fastblink reverse hidden/,
	],
	xterm => [
		{},  # rxvt except for blues
		qw/000000 CC0000 00CC00 CCCC00 4682B4 CC00CC 00CCCC E5E5E5
		   4C4C4C FF0000 00FF00 FFFF00 1E90FF FF00FF 00FFFF FFFFFF/,
	],
	tango => [
		{},  # default Gnome theme
		qw/2E3436 CC0000 4E9A06 C4A000 3465A4 75507B 06989A D3D7CF
		   555753 EF2929 8AE234 FCE94F 729FCF AD7FA8 34E2E2 EEEEEC/,
	],
	xkcd => [
		{
			title => 'human averages in xkcd survey results',
			href => 'http://blog.xkcd.com/2010/05/03/color-survey-results/',
		},
		qw/000000:black 650021:maroon  15b01a:green 6e750e:olive
		   01153e:navy  7e1e9c:purple  029386:teal  c5c9c7:silver
		   929591:grey  e50000:red     aaff32:lime  ffff14:yellow
		   0343df:blue  ed0dd9:fuchsia 00ffff:cyan  ffffff:white /,
	],
	android => [
		{
			href => 'http://developer.android.com/guide/practices/ui_guidelines/icon_design.html',
			title => 'recommended colour palette for Android icons',
		},
		qw/FFFFFF:white   BFBFBF:light   808080:medium  404040:dark
		   000000:black   6699FF:blue1   3366CC:blue2   003399:blue3
		   99CC33:green1  00CC00:green2  669933:green3  FFCC00:orange1
		   FF9900:orange2 FF6600:orange3 CC0000:red /,
	],
	app => [
		{
			name => 'Term.app',
		},
		qw/000000 C23621 25BC24 ADAD27 492EE1 D338D3 33BBC8 CBCCCD
		   818383 FC391F 31E722 EAEC23 5833FF F935F8 14F0F0 E9EBEB /,
	],
	putty => [
		{
			name => 'PuTTY',
		},
		qw/000000 BB0000 00BB00 BBBB00 0000BB BB00BB 00BBBB BBBBBB
		   555555 FF5555 55FF55 FFFF55 5555FF FF55FF 55FFFF FFFFFF /,
	],
	slutty => [
		{
			name => 'SluTTY',
			href => 'http://www.npjh.com/slutty.html',
			title => 'PuTTY fork with light colour scheme',
		},
		qw/000000 9C1D1D 6C9446 AC9A47 335786 8F6496 486768 E0DCDC
		   2F2F2F CD5757 8FC35B D1C45E 5C81A9 BC95B7 76CBCB EEEEEC /,
	],
	mac2 => [
		{
			name => 'MacII',
		},
		qw/FFFFFF FBF305 FF6403 DD0907 F20884 4700A5 0000D3 02ABEA
		   1FB714 006412 562C05 90713A C0C0C0 808080 404040 000000 /,
	],
	risc => [
		{
			name => 'RISC',  # v2/3
		},
		qw/FFFFFF DDDDDD BBBBBB 999999 777777 555555 333333 000000
		   004499 EEEE00 00CC00 DD0000 EEEEBB 558800 FFBB00 00BBFF /,
	],
	c64 => [
		{
			name => 'C=64',  # commodore 64/128
		},
		map {
			# 5-bit luma ± 2-bit colour angle
			my ($y, $neg, $hue) = split /(-)|\+/;

			# convert to yuv
			my ($u, $v) = (0, 0);
			if (defined $hue) {
				my $RAD = 3.14159;
				$hue *= $RAD / 8;
				$hue += $RAD if $neg;
				$u = cos $hue;
				$v = sin $hue;
			}

			# convert to rgb
			$y *= 255 / 32;
			$_ = $_ * 127.5 + 128 for $u, $v;
			Shiar_Sheet::Colour->newyuv($y, $u, $v)->rgb48;
		}
		qw/ 0    32  10+5 20-5 12+2 16-2 8+0  24-0
		    12+6 8+7 16+5 10   15   24-2 15+0 20 /,
	],
	msx1 => [
		{
			name => 'MSX',
		},
		map {
			my ($y, @c) = split /;/;
			$y *= 255;
			$_ = ($_ - .47) / .53 * 127.5 + 128 for @c;
			Shiar_Sheet::Colour->newyuv($y, @c)->rgb48;
		}
		qw/ 0.00;0.47;0.47 0.00;0.47;0.47 0.53;0.20;0.07 0.67;0.27;0.17
		    0.40;1.00;0.40 0.53;0.93;0.43 0.47;0.30;0.83 0.73;0.70;0.00
		    0.53;0.27;0.93 0.67;0.27;0.93 0.73;0.07;0.57 0.80;0.17;0.57
		    0.47;0.23;0.13 0.53;0.67;0.73 0.80;0.47;0.47 1.00;0.47;0.47 /,
	],
	msx2 => [
		{
			name => 'MSX2',
		},
		map { s{([0-7])}{sprintf '%02X', $1 / 7 * 255}egr }
		qw/ 000 000 161 373 117 237 511 267
		    711 733 661 663 141 625 555 777 /,
	],
	arnejmp => [
		{
			href => 'http://androidarts.com/palette/16pal.htm',
			title => "Arne's Japanese Machine Palette v3 (MSX)",
			name => 'A:JMP',
		},
		qw/ 000000 191028 46AF45 A1D685 453E78 7664FE 833129 9EC2E8
		    DC534B E18D79 D6B97B E9D8A1 216C4B D365C8 AFAAB9 F5F4EB /,
	],
	arnegame => [
		{
			href => 'http://androidarts.com/palette/16pal.htm',
			title => 'Generic 16 color game palette v20 by Arne Niklas Jansson',
			name => 'Arne',
		},
		qw/ 000000::void     9D9D9D::ash     FFFFFF::blind   BE2633::bloodred
		    E06F8B::pigmeat  493C2B::oldpoop A46422::newpoop EB8931::blaze
		    F7E26B::zornskin 2F484E::shade   44891A::leaf    A3CE27::slime
		    1B2632::night    005784::sea     31A2F2::sky     B2DCEF::cloud /,
	],
}
